@@ -13,7 +13,7 @@ class Load(Step.Step):
         self.preStep= "Ml"
         
     def startup(self):
-        super(self).startup()
+        super(Load,self).startup()
         self.startSubscriber()
     
     def doWork(self):
