@@ -22,6 +22,7 @@ class Step:
         self.paramsFile = 'Step.properties'
         self.logger = 'logStep'
         self.logFile = self.getRelativeFile( os.getcwd() +'\../logs/Step.log')
+        self.preStep= "St"
 
     # Needed for relative paths
     def getRelativeFile(self, filename):
@@ -73,7 +74,7 @@ class Step:
     
     def startSubscriber(self):
         self.subscriber = self.rC.pubsub()
-        self.subscriber.subscribe(self.taskID + "_" + self.step)
+        self.subscriber.subscribe(self.taskID + "_" + self.preStep)
 
     # declaring Redis connection parameters
     def makeRedisConn(self):
